.. _support:

Getting help
==============================

If you run into any problems when using Globus Provision, please contact us
through our mailing list:

.. centered:: ``provision-user@lists.globus.org``

Visit the `mailing list's page <https://lists.globus.org/mailman/listinfo/provision-user>`_
to subscribe to the list or to check out the list's archive. 

Reporting bugs, feature requests, etc.
======================================

Please report any bugs or feature requests through our Jira site: `http://jira.globus.org/browse/GP <http://jira.globus.org/browse/GP>`_
